macro_rules! test_http_compression_is_enabled {
() => { ... };
}Expand description
Define a test that checks that http compression is enabled for the client.
Requires httpmock in dev-dependencies
macro_rules! test_http_compression_is_enabled {
() => { ... };
}Define a test that checks that http compression is enabled for the client.
Requires httpmock in dev-dependencies